﻿namespace Infrastructure;

/// <summary>
/// controller基类
/// </summary>
[ApiController]
[Produces("application/json")]
[ProducesResponseType(StatusCodes.Status200OK)]
public class DefaultControllerBase : ControllerBase
{
    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData<T> Succeed<T>(T data, string message = "successful")
    {
        return new MessageData<T>(data, true, message);
    }

    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData Succeed(string message = "successful", int code = 200)
    {
        return new MessageData(true, message, code);
    }

    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData Fail(string message = "failed", int code = 500)
    {
        return new MessageData(false, message, code);
    }

    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData<T?> Fail<T>(string message = "failed", int code = 500)
    {
        return new MessageData<T?>(default, false, message, code);
    }

    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData<PageData<T>> SucceedPage<T>(
        int page,
        int totalItems,
        int pageSize,
        List<T> data,
        int totalPages,
        string message = "successful")
    {
        var pageData = new PageData<T>(page, pageSize, totalPages, totalItems, data);
        return new MessageData<PageData<T>>(pageData, true, message);
    }

    [NonAction]
    [ApiExplorerSettings(IgnoreApi = true)]
    public static MessageData<PageData<T>> SucceedPage<T>(PageData<T> page, string message = "successful")
    {
        return new MessageData<PageData<T>>(page, true, message);
    }
}