﻿using StackExchange.Redis;

namespace Infrastructure.Repository.Redis;

/// <summary>
/// redis访问仓储
/// </summary>
public interface IRedisBasketRepository
{
    Task<string> GetValue(string key);

    Task<T?> Get<T>(string key);

    Task<List<T>> GetValues<T>(string[] keys) where T : class;

    Task Set(string key, object? value, TimeSpan cacheTime);

    Task<bool> SetValues(Dictionary<string, object> valuePairs, TimeSpan cacheTime);

    Task<bool> Exist(string key);

    Task Remove(string key);

    Task Clear();

    Task<RedisValue[]> ListRangeAsync(string redisKey);

    Task<long> ListLeftPushAsync(string redisKey, string redisValue, int db = -1);

    Task<long> ListRightPushAsync(string redisKey, string redisValue, int db = -1);

    Task<long> ListRightPushAsync(string redisKey, IEnumerable<string> redisValue, int db = -1);

    Task<T> ListLeftPopAsync<T>(string redisKey, int db = -1) where T : class;

    Task<T> ListRightPopAsync<T>(string redisKey, int db = -1) where T : class;

    Task<string> ListLeftPopAsync(string redisKey, int db = -1);

    Task<string> ListRightPopAsync(string redisKey, int db = -1);

    Task<long> ListLengthAsync(string redisKey, int db = -1);

    Task<IEnumerable<string>> ListRangeAsync(string redisKey, int db = -1);

    Task<IEnumerable<string>> ListRangeAsync(string redisKey, int start, int stop, int db = -1);

    Task<long> ListDelRangeAsync(string redisKey, string redisValue, long type = 0, int db = -1);

    Task ListClearAsync(string redisKey, int db = -1);
}